#
# spec file for package ccfe
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ccfe
Version:        1.58
Release:        1.110
Summary:        Curses Command Frontend
License:        GPL-2.0+
Group:          System/Management
URL:            http://ccfe.altervista.org/
Source:         http://ccfe.altervista.org/dnload/ccfe-%{version}.tar.gz
Patch1:         ccfe-destdir.patch
BuildRequires:  perl(Curses)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(Sys::Hostname)
BuildRequires:  perl(Term::ANSIColor)
Requires:       perl-base = %{perl_version}
Requires:       perl(Curses)
Requires:       perl(File::Temp)
Requires:       perl(Sys::Hostname)
Requires:       perl(Term::ANSIColor)
BuildArch:      noarch
BuildRoot:      %{_tmppath}/build-%{name}-%{version}

%description
CCFE is a simple tool to quickly supply an interactive screen-oriented
interface to command line scripts and commands: it prompts users for the
informations needed to run them, and can be programmed with your preferred
shell to provide predefined selections and/or run-time defaults.

It provides:
* A generic curses form-based interface to enter options and arguments required by scripts/commands;
* A menu system to hierarchically organize them;
* A viewer to browse the standard output and standard error of invoked script/command.

In its simplest usage, you only have to describe the data type requested by the
command and specify the command itself: user interaction and screen layout are
automatically adapted so you don't have to care about it, but for complex
situations, CCFE is programmable with your preferred shell command language
interpreter and can propose lists of admitted values selectable by user for
parameters to enter.

%prep
%setup -q
%patch1
# fix shebang
sed -i 's|^#!/usr/bin/env perl|#!%{_bindir}/perl|' ccfe.pl

%build

%install
DESTDIR=%{buildroot} \
./install.sh \
    -b \
    -p "%{_prefix}" \
    -c "%{_sysconfdir}" \
    -l "%{_prefix}/lib" \
    -e "%{_bindir}" \
    -o "%{_localstatedir}/log/%{name}" \
    -m "%{_datadir}/%{name}/locale" \
    -a "%{_mandir}" \
    -d "%{_docdir}/%{name}"

find "%{buildroot}%{_prefix}/lib/ccfe/" -type f -exec chmod 0644 {} \;
rm -f "%{buildroot}%{_docdir}/%{name}"/install.sh
find "%{buildroot}%{_docdir}/%{name}/" -type f -exec chmod 0644 {} \;

install -d "%{buildroot}%{_localstatedir}/log/%{name}"

L="$PWD/ccfe.lang"
echo -n >"$L"
pushd "%{buildroot}%{_datadir}/%{name}/locale"
/bin/ls -1 | while read d; do
    echo "%lang($d) %doc %{_datadir}/%{name}/locale/$d" >>"$L"
    echo "%lang($d) %doc %{_datadir}/%{name}/locale/$d/ccfe" >>"$L"
done
popd #locale

%files -f ccfe.lang
%defattr(-,root,root)
%docdir %{_docdir}/%{name}
%dir %doc %{_docdir}/%{name}
%doc %{_docdir}/%{name}/*
%config(noreplace) %{_sysconfdir}/ccfe.conf
%config(noreplace) %{_sysconfdir}/ccfeinstall.conf
%{_bindir}/ccfe
%{_prefix}/lib/ccfe
%dir %{_datadir}/ccfe
%dir %{_datadir}/ccfe/locale
%dir %{_localstatedir}/log/%{name}
%{_mandir}/man1/ccfe.1%{ext_man}
%{_mandir}/man5/ccfe*.5%{ext_man}

%changelog
* Wed Feb  7 2018 aloisio@gmx.com
- Update to version v1.58
  * Fixed bug in fields value persistency.
  * Added CCFE_IWD environment variable (CCFE Invocation Working
    Directory).
  * Some cosmetics changes to several output.
  * Some changes were made to ccfe(1), ccfe_menu(5) and
    ccfe_form(5) manual pages.
  version 1.57
  * Fixed bug in init{} block: bad values initialization if they
    contains '=' character.
  * Added the ability to call forms from menus using arguments,
    (until this version, it was possible only calling forms from
    forms).
  * Changed default ccfe.conf: removed terminal-dependent settings
    and moved old ccfe.conf as ccfe.conf.console in samples
    directory.
  * Some changes were made to ccfe(1) and ccfe.conf(5) manual
    pages.
  version 1.56
  * Added <Shift>+<Tab> key functionality, and extended the
    ability to browse forward and backward the list of accepted
    values (with <Tab> and <Shift>+<Tab>) to any field where
    attribute list_cmd has source-type=const and
    list-type=single-val.
  * Added the metacharacter "*" to refer to all fields IDs in form
    actions: now is possible to refer to them with "%%{*}" instead
    "%%{id_0}%%{id_1}...%%{id_N}".
  * Some changes were made to ccfe(1), ccfe.conf(5) and
    ccfe_form(5) manual pages.
- Refreshed ccfe-destdir.patch
- Spec cleanup
* Thu Apr 19 2012 pascal.bleser@opensuse.org
- update to 1.55:
  * Added "-l" option to change library path
  * Added the ability to change library path by defining environment variable
    CCFE_LIB_DIR before run ccfe
  * Fixed bug: sometimes "ccfe -s" produces wrong shortcuts list
  * Added flag "~" in "ccfe -s" output to shortcuts referring menus and forms
    in user's home directory
- changes from 1.54:
  * Added "exec" action in menu items and forms to use ccfe as simple
    application launcher: run external command or application and return to
    O.S. when it is terminated
- changes from 1.53:
  * Fixed bug loading user private instance configuration
  * Added possibility to configure F11 and F12 keys
  * Changed info window horizontal position to better center-alignment
- changes from 1.52:
  * Fixed bug: segmentation fault on x86_64 architecture
* Sun Sep  4 2011 pascal.bleser@opensuse.org
- update to 1.51:
  * fixed bug: log file filemode forced to 0600
  * added "persist" field attribute to save fields value between CCFE
    executions
  * added "PERS_WRITE_ERROR_TITLE" and "PERS_WRITE_ERROR_MSG" in messages
    definition file
  * some changes were made to ccfe(1), ccfe_form(5) and ccfe_menu(5) manual
    pages
* Mon May  2 2011 pascal.bleser@opensuse.org
- update to 1.50:
  * fixed bug: sometimes CWD not correct when executing scripts located in
    $HOME/.ccfe subdirectory
  * some minor changes were made to ccfe(1) manual page
* Tue Apr 26 2011 pascal.bleser@opensuse.org
- update to 1.49:
  * fixes a bug in the Output Browser screen: lines exactly as long as the
    screen width were followed by an empty line
  * improved configuration files parsing for better diagnostics (when debugging
    is enabled)
  * adds an "end_marker" configuration parameter in the browser_global{}
    section
  * some changes were made to the ccfe.conf(5) manual page
* Sun Feb 27 2011 pascal.bleser@opensuse.org
- initial version (1.48)
